@@ -3,7 +3,7 @@ from django.contrib import admin
 
 class MultiuploaderAdmin(admin.ModelAdmin):
     search_fields = ["filename", "key_data"]
-    list_display = ["filename", "file",]
+    list_display = ["filename", "file"]
     list_filter = ["filename", "file"]
 
 admin.site.register(MultiuploaderFile, MultiuploaderAdmin)
\ No newline at end of file
